\name{DNAmixture}
\alias{DNAmixture}
\title{Create a DNA mixture model}
\usage{
  DNAmixture(data, k, C, database, K = character(0),
    reference.profiles = NULL, dir = character(0),
    domainnamelist = NULL, load = FALSE, write = FALSE,
    dyes = NULL, triangulate = TRUE, compile = TRUE,
    compress = TRUE, use.order = TRUE)
}
\arguments{
  \item{data}{A list of data.frames, one for each trace.
  Note, that in the special case of analysing just one
  trace, this still has to be specified as list(data). Each
  dataset should contain variables \code{marker},
  \code{allele}, and \code{frequency}. Optionally also a
  column for each reference profile specified in \code{K}.}

  \item{k}{Number of contributors.}

  \item{C}{A vector or list of thresholds for each dataset
  (trace).}

  \item{K}{Names of reference profiles.}

  \item{database}{A data.frame containing at least
  variables "marker", "allele", "frequency".}

  \item{reference.profiles}{A data.frame containing allele
  counts for each reference profile, if not specified in
  \code{data}.}

  \item{dir}{Location of network files.}

  \item{domainnamelist}{Names of marker-wise network files
  (without hkb-extension). Default is the set of markers.}

  \item{load}{Read networks from disk?}

  \item{write}{Save networks as hkb files?}

  \item{dyes}{A list containing a list of dyes indexed by
  markers}

  \item{triangulate}{Triangulate the networks? Default is
  to triangulate the network using a good elimination
  order.}

  \item{compile}{Compile the networks?}

  \item{compress}{Compress the network? Defaults to TRUE
  and is strongly recommended for models with a large
  number of contributors.}

  \item{use.order}{Should the default elimination order be
  used for triangulation? Otherwise the "total.weight"
  heuristic for triangulation in HUGIN is used.}
}
\value{
  An object of class DNAmixture
}
\description{
  A model for analysis of one or more DNA mixtures.
}
\details{
  For getting started, see in particular
  \code{\link{DNAmixtures}}.

  The names for known contributors can be chosen freely,
  whereas unknown contributors are always termed
  \code{U1,U2, ...}.

  If amelogenin is included in the analysis, the marker
  should be named "AMEL" and an integer coding such as X=0,
  Y=1, where X is assigned a lower number than Y, should be
  used. Note that in terms of amelogenin, the allele
  frequencies have a slighly different interpretation to
  that at other markers, in that they denote the
  probability of having an \emph{additional} X or Y to the
  X that all people have. Thus, a natural choice will be
  p(X)=p(Y)=0.5, denoting equal probability of a male or
  female contributor.
}
\examples{
data(MC15, MC18, USCaucasian)
DNAmixture(list(MC15, MC18), C = list(50,50), k = 3, K = c("K1", "K2"), database = USCaucasian)
DNAmixture(list(MC15, MC18), C = list(50,50), k = 3, K = c("K3", "K1", "K2"), database = USCaucasian)
}
\author{
  Therese Graversen
}

