\name{DNAmixtureData}
\alias{DNAmixtureData}
\title{Create a data set for a DNA mixture model}
\usage{
  DNAmixtureData(data, database, K = character(0),
    reference.profiles = NULL)
}
\arguments{
  \item{data}{Either one \code{data.frame} containing
  variables \code{markers} and \code{allele},
  \code{height}, or a list of one or more of such
  \code{data.frame}s, corresponding to each EPG. If a
  \code{data.frame} with reference profiles are not
  specified separately, these should be found amongst the
  datasets.}

  \item{K}{Names for reference profiles.}

  \item{database}{A \code{data.frame} with variables
  \code{marker}, \code{allele}, and allele frequency
  \code{frequency}.}

  \item{reference.profiles}{Optionally, a \code{data.frame}
  containing allele counts for each reference profile
  specified in \code{K}. There should be one variable for
  each name in \code{K} as well as variables \code{marker}
  and \code{allele}.}
}
\value{
  list of \code{data.frame}'s indexed by markers and
  containing variables \item{marker}{The STR marker}
  \item{allele}{Repeat number of the allele}
  \item{frequency}{Allele frequency} \item{height1, ...,
  heightN}{Peak heights for each of the N traces.}
  \item{...}{Known DNA profiles as labelled by \code{K}}
  \item{stutter.from}{For internal use. Where do the
  alleles get stutter from? A value of -1 means that the
  allele cannot receive stutter, corresponding to
  \code{gets_stutter} being false. \code{allele[i]}
  receives stutter from \code{allele[stutter.from[i]]}}
  \item{stutter.to}{As above. \code{allele[i]} can stutter
  to \code{allele[stutter.to[i]]}}
}
\description{
  Function for combining peak height data from a mixed
  trace as well as any reference profiles with allele
  frequencies from a specified database.
}
\details{
  The function is intended for internal use in
  \code{\link{DNAmixture}} and its purpose is to get data
  on a suitable form.  We allow for stutter to an allele
  one repeat number less. At the moment we consider
  possible only the alleles that are either specified
  through the data or the database. Any alleles not in the
  database will be assigned frequency NA, and it is then up
  to the user to decide on further actions. If a particular
  trace has no observations at a marker, the heights are
  set to NA, but if the trace has some observations, then
  missing heights are sat to 0. Note that we thus do not
  cater for the possibility that kits might not cover the
  same range of allelic values.
}
\examples{
## Create a dataset for two markers with each 3 observed alleles
epgdf <- data.frame(marker = rep(c("FGA", "TH01"), each = 3),
                    allele = c(18, 23, 27, 7, 8, 9.3), ## Observed alleles
                    height = c(100, 100, 200, 200, 100, 100), ## Peak heights
                    Anna = c(0,0,2,1,0,1),             ## Anna's profile
                    Peter = c(1,1,0,1,1,0))            ## Peter's profile

data(USCaucasian)
dat <- DNAmixtureData(epgdf, K = c("Anna", "Peter"), database = USCaucasian)
}
\author{
  Therese Graversen
}

