\name{boxplot.DNAmixture}
\alias{boxplot.DNAmixture}
\title{Plot simulated peak heights for multiple traces.}
\usage{
  \method{boxplot}{DNAmixture} (x, sims,
    traces = 1:x$ntraces, markers = x$markers, pw = 0.4,
    ylim = NULL, border = "grey", ...)
}
\arguments{
  \item{x}{A multiple traces DNA mixture.}

  \item{sims}{A set of simulated peak heights. See also
  \code{\link{rPeakHeight}}.}

  \item{traces}{Selected traces to plot.}

  \item{markers}{Selected markers to plot.}

  \item{pw}{Peaks are 2*pw wide.}

  \item{ylim}{Range of the y-axis.}

  \item{border}{Color of the boxes.}

  \item{...}{Arguments passed on to \code{boxplot}.}
}
\value{
  Invisibly the peak heights as used for the boxplots.
}
\description{
  A plot will be made for each combination of traces and
  markers specified, and it is up to the user to specify a
  layout for the plots (e.g. via calls to
  \code{\link{par}})
}
\examples{
data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = "K3", database = USCaucasian)
p <- mixpar(list(list(rho = 30, eta = 30, xi = 0.08, phi = c(U2 = 0.1, K3 = 0.2, U1 = 0.7)),
                 list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.9, K3 = 0.05, U2 = 0.05))))
rpm <- rPeakHeight(mix, p, nsim = 50, dist = "joint")
rpc <- rPeakHeight(mix, p, nsim = 50, dist = "conditional")
par(mfrow = c(2,2))
boxplot(mix, rpm, traces = 1:2, markers = "VWA") ## First row of plots
boxplot(mix, rpc, traces = 1:2, markers = "VWA") ## Second row of plots
mixK <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = c("K1", "K2", "K3"),
                    database = USCaucasian)
pK <- mixpar(list(list(rho = 30, eta = 30, xi = 0.08, phi = c(K2 = 0.1, K3 = 0.2, K1 = 0.7)),
                 list(rho = 30, eta = 30, xi = 0.08, phi = c(K2 = 0.1, K3 = 0.2, K1 = 0.7))))
rpmK <- rPeakHeight(mixK, pK, nsim = 50)
boxplot(mixK, rpmK)
}
\author{
  Therese Graversen
}

