\name{condPeakHeights}
\alias{condPeakHeights}
\title{Including or excluding peak height information.}
\usage{
  condPeakHeights(mixture, cond, markers = mixture$markers)
}
\arguments{
  \item{mixture}{A DNAmixture object.}

  \item{cond}{Condition on (all) observed peak heights?
  Propagate evidence (TRUE) or retract all evidence (FALSE)
  on all O-nodes.}

  \item{markers}{The set of markers for which the
  conditioning on peak heights should be done.}
}
\description{
  Condition on or retract information about all peak
  heights.
}
\note{
  Requires model parameters to be set.
}
\examples{
data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = c("K1", "K3"),
                   database = USCaucasian)
p <- mixpar(list(list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7)),
                list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7))))
## Set parameters and condition on peak heights
parameters(mix) <- p
condPeakHeights(mix, FALSE) ## No conditioning on peak heights
get.belief(mix$domains$VWA, "n_1_2")
condPeakHeights(mix, TRUE)  ## Condition on peak heights
get.belief(mix$domains$VWA, "n_1_2")
}
\author{
  Therese Graversen
}

