\name{map.genotypes}
\alias{map.genotypes}
\title{Maximum posterior genotypes of unknown contributors}
\usage{
  map.genotypes(mixture, pmin, U = seq_along(mixture$U),
    markers = mixture$markers,
    type = c("seen", "all", "unseen"))
}
\arguments{
  \item{mixture}{a DNA mixture}

  \item{pmin}{Minimum probabilities}

  \item{U}{The unknown contributors named by an integer
  vector}

  \item{markers}{Character vector of marker names}

  \item{type}{Currently one of \describe{
  \item{seen}{Alleles that are seen in at least one EPG}
  \item{all}{All alleles} \item{unseen}{Alleles that are
  not seen in any EPG (possibly redundant)} }}
}
\value{
  A list, which for each marker contains the maximum
  posterior configurations of genotypes above the specified
  probabilities \code{pmin}.
}
\description{
  For each marker, an list of configurations of genotypes
  for some or all unknown contributors is returned. The
  list contains all configurations with posterior
  probability higher than some specified \code{pmin}.
}
\details{
  Note that an error occurs the specified cutoff is lower
  than the highest posterior probability.
}
\examples{
data(MC18, USCaucasian, SGMplusDyes)
mix <- DNAmixture(list(MC18), k = 3, K = "K1", C = list(50), database = USCaucasian)
parameters(mix) <- mixpar(rho = list(30), eta = list(30), xi = list(0.07), phi = list(c(K1 = 0.7, U1 =0.2, U2 = 0.1)))
## Jointly best for all unknown contributors
mp <- map.genotypes(mix, pmin = 0.01, type = "seen")
summary(mp) ## Profiles as genotypes rather than allelecounts
## Marginally best for contributor U1
mpU1 <- map.genotypes(mix, pmin = 0.01, U = 1, type = "seen", markers = "D16S539")
summary(mpU1)
}

