\name{mixML}
\alias{mixML}
\title{Maximisation of the likelihood for one or more mixed traces of DNA}
\usage{
  mixML(mixture, pars, constraints = NULL, phi.eq = FALSE,
    val = NULL, trace = FALSE, ...)
}
\arguments{
  \item{mixture}{A \code{\link{DNAmixture}} object.}

  \item{pars}{A \code{\link{mixpar}} parameter used as a
  starting value for the optimisation.}

  \item{constraints}{Equality constraint function as
  function of an array of parameters.}

  \item{phi.eq}{Should the mixture proportions be the same
  for all traces? Defaults to FALSE.}

  \item{val}{Vector of values to be satisfied for the
  equality constraints.}

  \item{trace}{Print the evaluations of the
  likelihood-function during optimisation?}

  \item{...}{Further arguments to be passed on to
  \code{\link[Rsolnp]{solnp}}.}
}
\value{
  A list containing \item{mle}{The (suggested) MLE.}
  \item{lik}{The log of the likelihood (log e).} as well as
  the output from the optimisation.
}
\description{
  Maximisation of the likelihood for one or more mixed
  traces of DNA
}
\details{
  The fixed constraints for the model are \describe{
  \item{xi}{in [0,1].} \item{rho}{ in [0, Inf].}
  \item{eta}{ in [0, Inf].} \item{phi}{in [0, 1], sums to 1
  and if 2 or more unknowns then the mixture proportions
  for the unknown contributors are ordered decreasingly
  with the first trace determining the order.} } If, say,
  equal xi's are desired we can introduce constraints
  xi[1]-xi[2] = 0, etc.
}
\examples{
\dontrun{
data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = "K1", database = USCaucasian)
startpar <- mixpar(rho = list(24, 25), eta = list(37, 40), xi = list(0.08, 0.1),
                   phi = list(c(U1 = 0.05, K1 = 0.7, U2 = 0.25),
                                c(K1 = 0.7, U2 = 0.1, U1 = 0.2)))
eqxis <- function(x){ diff(unlist(x[,"xi"])) }
## Note that for these two traces, we do not expect phi to be equal.
## Here we set stutter equal for all traces
ml.diff <- mixML(mix, startpar, eqxis, val = 0, trace = TRUE, phi.eq = FALSE)
## Equal mixture proportions across traces
ml.eqphi <- mixML(mix, startpar, eqxis, val = 0, trace = TRUE, phi.eq = TRUE)
}
}
\author{
  Therese Graversen
}
\seealso{
  \code{\link{DNAmixture}}
}

