\name{predict.DNAmixture}
\alias{predict.DNAmixture}
\title{Various probabilities in a fitted DNA mixture model}
\usage{
  \method{predict}{DNAmixture} (object, pars,
    dist = c("joint", "conditional", "prequential"),
    markers = object$markers, by.allele = TRUE, ...)
}
\arguments{
  \item{object}{A \code{\link{DNAmixture}} object}

  \item{pars}{Array of model parameters}

  \item{markers}{The set of markers of interest}

  \item{dist}{One of "joint", "conditional", and
  "prequential". If there are only known contributors,
  these are all the same since, under the model, peak
  heights are condtionally independent given profiles of
  the contributors.}

  \item{by.allele}{If \code{dist = "prequential"} then the
  order in which we condition on traces and alleles
  matters. \code{by.allele = TRUE} will proceed through
  alleles in increasing repeat number, and for each allele
  condition on one trace at the time. If false, the
  conditioning is done by traces and then alleles within
  these.}

  \item{...}{Not used}
}
\value{
  A list with one data.frame per marker containing various
  probabilities for diagnostics \item{unseen}{The
  probability of not seeing a peak, i.e. no peak or a peak
  falling below the threshold} \item{seen}{The probability
  of seeing the allele} \item{smaller}{The probability of
  seeing a smaller peak than the one observed}
  \item{larger}{The probability of seeing a larger peak
  than the one observed}
}
\description{
  Various probabilities in a fitted DNA mixture model
}
\details{
  For a mixture with unknown contributors, the
  probabilities are computed with respect to one of three
  distributions: \describe{ \item{joint}{Default. No
  conditioning on observed peak heights.}
  \item{conditional}{Condition on heights \eqn{Z_b} (via.
  \eqn{O_b}) for \eqn{b <= a}.}
  \item{prequential}{Condition on heights \eqn{Z_b, b <
  a}.} } If all contributors are fixed, all distributions
  are the same due to independence of the peak heights.
}
\examples{
data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50,50), k = 3, K = c("K1", "K3", "K2"),
database = USCaucasian)
p <- mixpar(list(
                list(rho = 30, eta = 30, xi = 0.08, phi = c(K2 = 0.1, K3 = 0.2, K1 = 0.7)),
                list(rho = 3, eta = 30, xi = 0.08, phi = c(K2 = 0.4, K3 = 0.5, K1 = 0.1))))
predict(mix, p)
}
\author{
  Therese Graversen
}

