\name{prequential.score}
\alias{prequential.score}
\title{Calculate prequential scores}
\usage{
  prequential.score(mixture, pars,
    markers = mixture$markers, by.allele = TRUE)
}
\arguments{
  \item{mixture}{A DNAmixture model}

  \item{pars}{An array of parameters}

  \item{markers}{An ordering of the markers, possibly a
  subset of the markers only.}

  \item{by.allele}{Should conditioning be done allele-wise
  (TRUE) or trace-wise (FALSE). Defaults to TRUE.}
}
\value{
  A data.frame, which contains the output from
  \code{\link{predict}} as well as columns Y, EY, VY,
  corresponding to the log-score and its mean and variance.
  Finally the variable \code{score} is added, which is the
  normalised cumulative log-score.
}
\description{
  Calculate prequential scores
}
\examples{
data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50,50), k = 3, K = c("K1", "K3"), database = USCaucasian)
p <- mixpar(list(
                list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7)),
                list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7))))
preq <- prequential.score(mix, pars = p)
plot(preq, col = preq$trace)
## Annotate using repeat numbers
text(preq$score, labels = preq$allele, pos = c(1,3), col = preq$trace, cex = 0.6)
}
\author{
  Therese Graversen
}

