\name{qqpeak}
\alias{qqpeak}
\title{QQ-plot for the distribution of observed peak heights.}
\usage{
  qqpeak(x, pars,
    dist = c("joint", "conditional", "prequential"),
    by.allele = TRUE, xlab = "Uniform quantiles",
    ylab = NULL, xlim = NULL, ylim = xlim, ...)
}
\arguments{
  \item{x}{A DNAmixture model.}

  \item{pars}{Model parameters.}

  \item{dist}{Joint, conditional or prequential.}

  \item{xlab}{Legend for the x-axis.}

  \item{ylab}{Legend for y-axis.}

  \item{xlim}{Range of x-axis. Default is a plot with equal
  ranges on the x- and y-axis.}

  \item{ylim}{Range of y-axis.}

  \item{by.allele}{Order of conditioning when \code{dist =
  "prequential"}. See \code{\link{predict.DNAmixture}}}

  \item{...}{Other arguments for \code{plot}}
}
\value{
  A \code{data.frame} containg quantiles P(Z < z_obs | Z >
  0) in the specified model, together with other output
  from \code{predict.DNAmixture}.
}
\description{
  QQ-plot for the distribution of observed peak heights.
}
\examples{
data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = c("K1", "K3"), database = USCaucasian)
p <- mixpar(list(list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7)),
                 list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7))))
qq <- qqpeak(mix, pars = p, dist = "prequential")
}
\author{
  Therese Graversen
}

