\name{rPeakHeight}
\alias{rPeakHeight}
\title{Simulate peak heights from a DNA mixture model.}
\usage{
  rPeakHeight(mixture, pars, nsim = 1,
    markers = mixture$markers,
    dist = c("joint", "conditional"), use.threshold = TRUE,
    ...)
}
\arguments{
  \item{mixture}{A DNAmixture.}

  \item{pars}{Model parameters.}

  \item{nsim}{Number of simulations for each allele.}

  \item{markers}{Subset of markers to simulate}

  \item{dist}{How should observed peak heights be taken
  into account? Possible choices are "joint" or
  "conditional".}

  \item{use.threshold}{Should peak heights under the
  detection threshold C be set to 0? Defaults to TRUE,
  corresponding to simulating under the model fitted.}

  \item{...}{Not used.}
}
\value{
  A list of one three-way array per marker. The margins
  are: trace, allele, sample.
}
\description{
  A set of peak heights is sampled for each trace. Note
  that as the traces can cover different sets of markers,
  so will the simulated peak heights.  If there are unknown
  contributors, their genotypes are sampled from the
  networks in the \code{DNAmixture}, but these genotypes
  are not stored.
}
\examples{
data(MC15, MC18, USCaucasian)
mixD <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = c("K1", "K3"), database = USCaucasian)
pD <- mixpar(list(
                list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7)),
                list(rho = 30, eta = 30, xi = 0.08, phi = c(U1 = 0.1, K3 = 0.2, K1 = 0.7))))
rpj <- rPeakHeight(mixD, pD, nsim = 5, dist = "joint")
rpc <- rPeakHeight(mixD, pD, nsim = 5, dist = "conditional")
mixP <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = c("K1", "K3", "K2"), database = USCaucasian)
pP <- mixpar(list(
                list(rho = 30, eta = 30, xi = 0.08, phi = c(K2 = 0.1, K3 = 0.2, K1 = 0.7)),
                list(rho = 30, eta = 30, xi = 0.08, phi = c(K2 = 0.1, K3 = 0.2, K1 = 0.7))))
rpk <- rPeakHeight(mixP, pP, nsim = 5)
}
\author{
  Therese Graversen
}

