\name{set.CPT.O}
\alias{set.CPT.O}
\title{Set tables for binary nodes O_a.}
\usage{
  set.CPT.O(domain, rho, xi, eta, phi, heights, C,
    n.unknown, n_K, O, gets_stutter, can_stutter,
    stutter.from)
}
\arguments{
  \item{domain}{A \code{hugin.domain} modelling one marker}

  \item{rho}{rho}

  \item{xi}{xi}

  \item{eta}{eta}

  \item{phi}{phi}

  \item{heights}{Peak heights}

  \item{C}{Detection threshold}

  \item{n.unknown}{Number of unknown contributors}

  \item{n_K}{Allelecounts for known contributors}

  \item{O}{Vector of names for binary nodes}

  \item{gets_stutter}{Does the allele receive stutter? A
  boolean vector.}

  \item{can_stutter}{Can the allele stutter?}

  \item{stutter.from}{From which allele does the stutter
  come?}
}
\value{
  Scaling factors to be set as evidence when conditioning
  on the peak heights.
}
\description{
  Function for setting the tables on all nodes O_a at a
  marker, using peak heights and a set of parameters. The
  returned evidence can be used for conditioning on
  observed peak heights.
}
\details{
  The function sets probabilities in CPT according to
  whether a peak is observed or not. If a peak is seen, the
  conditional distribution is defined as \deqn{P(O_a = TRUE
  | allelecounts) = f(Z_a | allelecounts, pars)/k_a} and
  likelihood-evidence \eqn{(0, k_a)} for the states (FALSE,
  TRUE) is returned. If the allele is not seen, the CPT is
  set using \deqn{P(O_a = FALSE | allelecounts) = P(Z_a < C
  | allelecounts, pars)}, in which case evidence (1,0) is
  returned.

  Currently the returned evidence is also entered in the
  network, but not propagated. In future versions of the
  package, this is likely to change, such that evidence is
  no longere entered automatically.

  Note that the detection threshold and model parameters
  can be specified as vectors, and so it is possible to use
  allele-specific values, if desired. This also holds for
  the functions \code{\link{set.CPT.D}} and
  \code{\link{set.CPT.Q}}.
}
\section{Technical comments}{
  For the sake of speed and saving memory, only
  probabilities for the CPT of O_a are calculated, and not
  the entire table.  The parent nodes are \code{n_i_a} and
  possibly \code{n_i_(a+1)} for all unknown contributors i.
  The layout of the table relies in particular on the fact
  that all nodes have a statespace {0,1,2}, which this is
  *not* checked anywhere. Thus, if other types of
  allele-count-nodes \code{n_i_a} are introduced (such as
  could be relevant for Amelogenin), the function should be
  changed accordingly.

  If invalid tables are set -- for instance if very extreme
  parameter values are used -- then any subsequent
  propagation will fail. No roll-back functionality has so
  far been implemented to fix this, and the easiest
  solution is to re-fit the mixture model.
}

