\name{varEst}
\alias{varEst}
\title{Estimated asymptotic variance matrix for MLE}
\usage{
  varEst(mixture, mle, npars, method = "Richardson", ...)
}
\arguments{
  \item{mixture}{A \code{\link{DNAmixture}}.}

  \item{mle}{A \code{mixpar}, typically obtained by
  \code{mixML}.}

  \item{npars}{A list containing the number of each of the
  four parameters rho, eta, xi and phi. Allowed values are
  0 (fixed value, but might differ across traces), 1 (equal
  across traces) and "number of traces" (one for each
  trace).}

  \item{method}{Method for numeric differentiation used in
  \code{\link[numDeriv]{hessian}}}

  \item{...}{Not used}
}
\description{
  Estimated asymptotic variance matrix for MLE
}
\details{
  As the user can infer highly customized constraints on
  the model parameters, it is a complicated matter to write
  a generic function for computing the asymptotic variance
  matrix. We have thus restricted attention to the case
  where each parameter can be either \emph{fixed},
  \emph{equal} across traces, or \emph{different} accross
  traces.
}
\examples{
data(MC18, USCaucasian)
mixmult <- DNAmixture(list(MC18), C = list(50), k = 3, K = c("K1", "K2"), database = USCaucasian)
startpar <- mixpar(rho = list(30), eta = list(28), xi = list(0.08),
                   phi = list(c(U1 = 0.2, K1 = 0.7, K2 = 0.1)))
ml.mult <- mixML(mixmult, startpar, trace = TRUE)
Vmult <- varEst(mixmult, ml.mult$mle, list(rho=1,eta=1,xi=1,phi=1))

data(MC15, MC18, USCaucasian)
mix <- DNAmixture(list(MC15, MC18), C = list(50, 38), k = 3, K = c("K1", "K2"),
database = USCaucasian)
startpar <- mixpar(rho = list(30, 30), eta = list(28, 35), xi = list(0.08, 0.1),
                   phi = list(c(U1 = 0.05, K1 = 0.7, K2 = 0.25),
                                c(K1 = 0.7, K2 = 0.1, U1 = 0.2)))
eqxis <- function(x){ diff(unlist(x[,"xi"])) }
## Here we set stutter equal for all traces
ml.diff <- mixML(mix, startpar, eqxis, val = 0, trace = TRUE, phi.eq = FALSE)
V.diff <- varEst(mix, ml.diff$mle, list(rho=2,eta=2,xi=1,phi=2))

## Fixing stutter to 0.07
xival <- function(x){unlist(x[,"xi"])}
ml.eq <- mixML(mix, startpar, xival, val = c(0.07, 0.07), trace = TRUE, phi.eq = FALSE)
V.eq <- varEst(mix, ml.eq$mle, list(rho=2,eta=2,xi=0,phi=2))
}

